@@ -282,6 +282,41 @@ def run_objective_function(
     return list(scalarized_values), feasibility_indicators
 
 
+def parallel_optimization_function(
+    optimization_function_parameters,
+    input_queue,
+    output_queue,
+    proc,
+    optimization_function,
+):
+    temporary_parameters = optimization_function_parameters.copy()
+
+    while True:
+        input_parameters = input_queue.get()
+        if input_parameters is None:
+            input_queue.task_done()
+            break
+
+        configurations, split_index, conf_index = (
+            input_parameters["partition"],
+            input_parameters["split_index"],
+            input_parameters["conf_index"],
+        )
+        temporary_parameters["configurations"] = configurations
+        scalarized_values, feasibility_indicators = optimization_function(
+            **temporary_parameters
+        )
+        output_queue.put(
+            {
+                "scalarized_values": scalarized_values,
+                "feasibility_indicators": feasibility_indicators,
+                "split_index": split_index,
+                "conf_index": conf_index,
+            }
+        )
+        input_queue.task_done()
+
+
 def local_search(
     local_search_starting_points,
     local_search_random_points,
@@ -351,11 +386,14 @@ def local_search(
         ("Total RS time %10.4f sec\n" % ((sampling_time - t0).total_seconds()))
     )
 
+    # check that the number of configurations are not less than the number of CPUs
+    min_number_of_configs = min(len(uniform_configurations), len(prior_configurations))
+    if min_number_of_configs < number_of_cpus:
+        number_of_cpus = min_number_of_configs
+
     # to avoid having partitions with no samples, it's necessary to compute a floor for the number of partitions for small sample spaces
     # alternatively, an arbitraty number of samples could be set for the number of points where we do not have to partition (since it will be quick anyway)
-    min_number_per_partition = (
-        min(len(uniform_configurations), len(prior_configurations)) / number_of_cpus
-    )
+    min_number_per_partition = min_number_of_configs / number_of_cpus
     partitions_per_cpu = min(10, int(min_number_per_partition))
     if number_of_cpus == 1:
         function_values_uniform, feasibility_indicators_uniform = optimization_function(
@@ -365,38 +403,8 @@ def local_search(
             configurations=prior_configurations, **optimization_function_parameters
         )
     else:
-        # define function to run in parallel (nested to avoid more argument passing and easier to follow
-        def parallel_optimization_function(
-            optimization_function_parameters, input_queue, output_queue, proc
-        ):
-            temporary_parameters = optimization_function_parameters.copy()
-
-            while True:
-                input_parameters = input_queue.get()
-                if input_parameters is None:
-                    input_queue.task_done()
-                    break
-
-                configurations, split_index, conf_index = (
-                    input_parameters["partition"],
-                    input_parameters["split_index"],
-                    input_parameters["conf_index"],
-                )
-                temporary_parameters["configurations"] = configurations
-                scalarized_values, feasibility_indicators = optimization_function(
-                    **temporary_parameters
-                )
-                output_queue.put(
-                    {
-                        "scalarized_values": scalarized_values,
-                        "feasibility_indicators": feasibility_indicators,
-                        "split_index": split_index,
-                        "conf_index": conf_index,
-                    }
-                )
-                input_queue.task_done()
-
         # the number of splits of the list of input points that each process is expected to handle
+
         uniform_partition_fraction = len(uniform_configurations) / (
             partitions_per_cpu * number_of_cpus
         )
@@ -437,7 +445,13 @@ def local_search(
         processes = [
             Process(
                 target=parallel_optimization_function,
-                args=(optimization_function_parameters, input_queue, output_queue, i),
+                args=(
+                    optimization_function_parameters,
+                    input_queue,
+                    output_queue,
+                    i,
+                    optimization_function,
+                ),
             )
             for i in range(number_of_cpus)
         ]
@@ -747,7 +761,7 @@ def local_search(
     result_array = {}
     for i in range(number_of_configurations):
         result = output_queue.get()
-        sys.stdout.write_to_logfile(result["logstring"])
+        sys.stdout.write_to_logfile(result["logstring"], msg_is_verbose=True)
         result_array = concatenate_data_dictionaries(result_array, result["data_array"])
     data_array = concatenate_data_dictionaries(result_array, data_array)
 
@@ -899,6 +913,7 @@ def main(config, black_box_function=None, profiling=None):
 
     log_file = deal_with_relative_and_absolute_path(run_directory, config["log_file"])
     sys.stdout.change_log_file(log_file)
+    sys.stdout.set_verbose_mode(config["verbose_logging"])
     if hypermapper_mode == "client-server":
         sys.stdout.switch_log_only_on_file(True)
 
